/* ver.B.b16.01(BLAZE) */


#include "version.h"


VERSION machine_code_version = {
	"MA.code",
	"win.xp.Interface",
	"(C) 2000-2007 Hirohisa Mori",
	"ver.B.b16.01(BLAZE)",
	2007,5,30,
	0,
	"machine (win.xp) dependent library ",
};

